@@ -48,9 +48,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         isResumePlayback(false),
         isMainToolbarVisible(false),
         isSeekSliderShown(true),
-        fileListWidgetItemIndexToDelete(-1),
-        forceUpdatePlayList(false),
-        isSubDirScanned(false)
+        fileListWidgetItemFileToDelete(QString())
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
@@ -67,21 +65,12 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     if(SymfonieDb::getInstance()->getSetting("is_seekSlider_visible", QVariant(0)).toInt() == 0){
         this->isSeekSliderShown = false;
         this->ui->sliderPanel->hide();
-
     }else{
         this->isSeekSliderShown = true;
         this->ui->sliderPanel->show();
     }
 
 
-    //disable scroll panning
-    QAbstractKineticScroller *scroller = this->ui->fileListWidget->property("kineticScroller")
-                                         .value<QAbstractKineticScroller *>();
-    if (scroller){
-        scroller->setOvershootPolicy(QAbstractKineticScroller::OvershootAlwaysOff);
-    }
-
-
     //set up menus
     orientationGroup = new QActionGroup(this);
     orientationGroup->setExclusive(true);
@@ -146,7 +135,6 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     connect(this->ui->menuActionEqualizer, SIGNAL(triggered()), this, SLOT(showEqualizerWindowSlot()));
 
-    connect(this->ui->menuActionSupportSymfonie, SIGNAL(triggered()), this, SLOT(supportSymfonieSlot()));
 
 
     connect(this->ui->menuActionAbout, SIGNAL(triggered()), this, SLOT(showAboutWindowSlot()));
@@ -206,9 +194,9 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
                                                 tr("Switch Orientation"), ui->mainToolBar);
 
 
-   // this->showInfoWindowAction  = new QAction(tr("Seek"), ui->mainToolBar);
-   // this->showInfoWindowAction->setCheckable(true);
-
+    this->showInfoWindowAction  = new QAction(tr("Seek"), ui->mainToolBar);
+    this->showInfoWindowAction->setCheckable(true);
+    connect(showInfoWindowAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
     this->showToolBar2Action  = new QAction(QIcon::fromTheme("general_speaker"), tr("Show Volume Control"), ui->mainToolBar);
@@ -219,27 +207,10 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     this->goHomeAction = new QAction(QIcon::fromTheme("general_device_root_folder"), tr("Go Home"), ui->mainToolBar);
     connect(goHomeAction, SIGNAL(triggered()), this, SLOT(goHomeSlot()));
 
-    this->shuffleAction = new QAction(QIcon::fromTheme("mediaplayer_default_shuffle"), tr("Shuffle"), ui->mainToolBar);
-    this->shuffleAction->setCheckable(true);
-    connect(this->shuffleAction, SIGNAL(toggled(bool)), this, SLOT(shuffleSlot(bool)));
-
-    this->repeatAction = new QAction(QIcon::fromTheme("imageviewer_crop"), tr("Repeat"), ui->mainToolBar);
-    this->repeatAction->setCheckable(true);
-    connect(this->repeatAction, SIGNAL(toggled(bool)), this, SLOT(repeatSlot(bool)));
 
 
-    this->scanDirAction = new QAction(tr("Sub"), ui->mainToolBar);
-    this->scanDirAction->setCheckable(true);
-    this->connect(this->scanDirAction, SIGNAL(toggled(bool)), this, SLOT(scanSubFolderPressedSlot(bool)));
-
-
-
-
-/*
     this->showSpeedDialogAction = new QAction(QIcon::fromTheme("general_clock"), tr("Go Home"), ui->mainToolBar);
     this->connect(showSpeedDialogAction, SIGNAL(triggered()), this, SLOT(showSpeedDialogSlot()));
-*/
-
 
 
     this->goToCurDir = new QAction(QIcon::fromTheme("imageviewer_rotate"), tr("Go to current directory"), ui->mainToolBar);
@@ -255,7 +226,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(this->player->getMediaObject(), SIGNAL(tick(qint64)), this, SLOT(playerTickSlot(qint64)));
 
 
-   // connect(nextAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
+    connect(nextAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
     // this->ui->volumePanel->layout()->addWidget(this->volumeSlider);
@@ -304,7 +275,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     this->ui->fileListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
+    // connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
 
 
 
@@ -351,18 +322,11 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 }
 
 void MainWindow::deleteFileSlot(){
-    if(this->fileListWidgetItemIndexToDelete < 0){
-        qDebug() << "Nothing selected. this->fileListWidgetItemIndexToDelete" << this->fileListWidgetItemIndexToDelete;
-        return;
-    }
-    QString filePath = this->currentPlayList
-                       ->get(this->fileListWidgetItemIndexToDelete)
-                       ->getName();
-    qDebug() << "Trying to delete file: " << filePath;
+    qDebug() << "Trying to delete file: " <<this->fileListWidgetItemFileToDelete;
 
     QMessageBox msgBox;
     // msgBox.setText(tr("File Deletion"));
-     msgBox.setInformativeText(tr("Are you sure you want to delete this file?\n") + filePath);
+     msgBox.setInformativeText(tr("Are you sure you want to delete this file?\n") + this->fileListWidgetItemFileToDelete);
      msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
      msgBox.setDefaultButton(QMessageBox::No);
      int ret = msgBox.exec();
@@ -373,51 +337,24 @@ void MainWindow::deleteFileSlot(){
      }
 
 
-    QFileInfo info = QFileInfo(filePath);
+    QFileInfo info = QFileInfo(this->fileListWidgetItemFileToDelete);
     if(!info.exists() || !info.isFile()){
         qDebug() << "deleteFileSlot: not a filed, operation skipped.";
         return;
     }
 
-    if(
-            QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0 &&
-            this->fileListWidgetItemIndexToDelete == this->getPlayer()->getCurrentPlaybackIndex()){
-        this->getPlayer()->stop();
-        this->forceUpdatePlayList = true;
-    }
+  //  this->getPlayer()->getMediaObject()->stop();
 
-
-
-    if(!QFile::remove(filePath)){
-        qDebug() << "deleteFileSlot: deletion failed: "<< filePath;
-        QMessageBox msgBox;
-        msgBox.setInformativeText(tr("Unable to delete selected file."));
-        msgBox.exec();
+    if(!QFile::remove(this->fileListWidgetItemFileToDelete)){
+        qDebug() << "deleteFileSlot: deletion failed: "<< this->fileListWidgetItemFileToDelete;
         return;
     }
 
-
     this->getPlayer()->scanDir(this->getCurrentDiretory());
 
 
 }
 
-
-
-
-void MainWindow::scanSubFolderPressedSlot(bool isChecked){
-  qDebug() << this->getPlayer()->getCurrentDirectory() << this->getCurrentDiretory();
-
-  this->getPlayer()->stop();
-
-  if(isChecked){
-      this->getPlayer()->scanDirRecursive(this->getCurrentDiretory());
-  }else{
-      this->getPlayer()->scanDir(this->getCurrentDiretory());
-  }
-
-}
-
 void MainWindow::fileListItemContextMenu(const QPoint &pos){
 
     QListWidgetItem *item = this->ui->fileListWidget->itemAt(pos);
@@ -427,24 +364,18 @@ void MainWindow::fileListItemContextMenu(const QPoint &pos){
         return;
     }
 
-      itemIndex = item->data(Qt::UserRole).toInt();
-
-    if(this->currentPlayList->get(itemIndex)->getItemType() != SymfoniePlayListItemFile::File){
-        return;
-    }
-
-
+    itemIndex = item->data(Qt::UserRole).toInt();
 
     SymfonieQMenu *menu = new SymfonieQMenu();
 
 
-
-    this->fileListWidgetItemIndexToDelete = itemIndex;
-    menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
-
+    if(this->getPlayer()->getPlayList()->get(itemIndex)->getItemType() == SymfoniePlayListItemFile::File){
+        this->fileListWidgetItemFileToDelete = this->getPlayer()->getPlayList()->get(itemIndex)->getName();
+        menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
+    }
     menu->exec(this->mapToGlobal(pos));
-    // delete menu;
-    this->fileListWidgetItemIndexToDelete = -1;
+   // delete menu;
+    this->fileListWidgetItemFileToDelete = QString();
 
 
 }
@@ -463,26 +394,20 @@ MainWindow::~MainWindow()
     delete prevAction;
     delete nextAction;
 
-    delete this->repeatAction;
-    delete this->shuffleAction;
-
     delete toggleFullScreenAction;
     delete switchOrientationAction;
-    //delete showInfoWindowAction;
+    delete showInfoWindowAction;
     delete showToolBar2Action;
 
-    //delete showSpeedDialogAction;
+    delete showSpeedDialogAction;
 
     delete goUpAction;
     delete goHomeAction;
     delete goToCurDir;
-
     if(this->timerWindow != NULL){
         delete this->timerWindow;
     }
-
-
-
+    delete this->player;
 
     delete this->equalizerWindow;
 
@@ -502,9 +427,6 @@ MainWindow::~MainWindow()
         delete this->speedDialog;
     }
 
-   // @todo find out why this cause segmentation error
-    //delete this->player;
-
 }
 
 void MainWindow::showSpeedDialogSlot(){
@@ -512,16 +434,16 @@ void MainWindow::showSpeedDialogSlot(){
         this->speedDialog = new SymfonieSpeedDialog(this);
         this->connect(
                 speedDialog,
-                SIGNAL(speedChangedSignal(double)),
+                SIGNAL(speedChangedSignal(float)),
                 this,
-                SLOT(showSpeedDialogSliderChangedSlot(double))
+                SLOT(showSpeedDialogSliderChangedSlot(float))
                 );
     }
 
     this->speedDialog->exec();
 }
 
-void MainWindow::showSpeedDialogSliderChangedSlot(double value){
+void MainWindow::showSpeedDialogSliderChangedSlot(float value){
     qDebug() << "Speed value from dialog: " << value;
     this->getPlayer()->setSpeed(value);
 }
@@ -538,15 +460,11 @@ void MainWindow::setupToolBarButtonsLandscape(){
     this->ui->mainToolBar->addAction(prevAction);
     this->ui->mainToolBar->addAction(playAction);
     this->ui->mainToolBar->addAction(nextAction);
-   // this->ui->mainToolBar->addAction(scanDirAction);
 
-    //this->ui->mainToolBar->addAction(showInfoWindowAction);
+    this->ui->mainToolBar->addAction(showInfoWindowAction);
     this->ui->mainToolBar->addAction(this->showToolBar2Action);
 
-    this->ui->mainToolBar->addAction(this->shuffleAction);
-    this->ui->mainToolBar->addAction(this->repeatAction);
-
-    //this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
+    this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
     //this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
 
     this->ui->mainToolBar2->hide();
@@ -564,18 +482,15 @@ void MainWindow::setupToolBarButtonsPortrait(){
     this->ui->mainToolBar2->addAction(prevAction);
     this->ui->mainToolBar2->addAction(playAction);
     this->ui->mainToolBar2->addAction(nextAction);
-   // this->ui->mainToolBar2->addAction(scanDirAction);
 
-    //this->ui->mainToolBar2->addAction(showInfoWindowAction);
+    this->ui->mainToolBar2->addAction(showInfoWindowAction);
     this->ui->mainToolBar2->addAction(this->showToolBar2Action);
 
 
     this->ui->mainToolBar->addAction(this->goHomeAction);
     this->ui->mainToolBar->addAction(this->goUpAction);
     this->ui->mainToolBar->addAction(this->goToCurDir);
-    this->ui->mainToolBar->addAction(this->shuffleAction);
-    this->ui->mainToolBar->addAction(this->repeatAction);
-   // this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
+    this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
 
     // this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
 
@@ -623,32 +538,6 @@ void MainWindow::setOrientationMode(int mode){
 }
 
 
-void MainWindow::shuffleSlot(bool isChecked){
-
-    if(isChecked){
-        qDebug() << "enabling shuffle";
-        this->getPlayer()->enableShuffle();
-
-    }else{
-        qDebug() << "disabling shuffle";
-        this->getPlayer()->disableShuffle();
-    }
-}
-
-void MainWindow::repeatSlot(bool isChecked){
-    if(isChecked){
-        qDebug() << "repeat enabled";
-        this->getPlayer()->enableRepeat();
-    }else{
-        qDebug() << "repeat disabled";
-        this->getPlayer()->disableRepeat();
-    }
-}
-
-void MainWindow::supportSymfonieSlot(){
-    QDesktopServices::openUrl(QUrl("http://thecodecentral.com/symfonie#dd", QUrl::TolerantMode));
-}
-
 void MainWindow::toggleFullScreenOn(){
     toggleFullScreen(true);
 }
@@ -683,7 +572,7 @@ void MainWindow::clearTimerSlot(){
 }
 
 void MainWindow::setMenuActionTimerText(int time){
-
+    //qDebug() << "--------------------------setMenuActionTimerText: "<< time;
     if(time == 0){
         this->ui->menuActionTimer->setText("Sleep Timer");
     }else{
@@ -743,25 +632,10 @@ void MainWindow::showVolumeDialogSlot(){
 
         this->volumeDialog->layout()->addWidget(this->volumeSlider);
 
-
-
-        qDebug() << "showVolumeDialogSlot"<<this->isSeekSliderShown;
-
-        this->volumeDialog->getShowSeekbarButton()->setChecked(this->isSeekSliderShown);
-
-       this->connect(this->volumeDialog, SIGNAL(speedChangedSignal(double)),
-                this, SLOT(showSpeedDialogSliderChangedSlot(double)));
-
-
-
-       this->connect(
-               this->volumeDialog->getShowSeekbarButton(),
-               SIGNAL(toggled(bool)),
-               this,
-               SLOT(showInfoWindowSlot(bool))
-             );
-
-
+        /*
+        connect(this->volumeDialog, SIGNAL(finished(int)),
+                this, SLOT(volumeDialogClosedSlot(int)));
+                */
     }
 
     this->volumeDialog->exec();
@@ -825,6 +699,7 @@ void MainWindow::goUpSlot(){
 
     QDir homeDir = QDir(QDir::homePath() + "/MyDocs");
     QDir mediaDir = QDir("/media");
+    qDebug() << "sdflskjadf=-===========: "<< homeDir.canonicalPath() << this->getCurrentDiretory();
 
 
     if(this->getCurrentDiretory().length() == 0 ||
@@ -853,7 +728,6 @@ bool MainWindow::saveLastDir(){
 
 
 void MainWindow::saveState(){
-
     this->saveLastDir();
     // qDebug() << "curent time: "<<this->getPlayer()->getMediaObject()->currentTime();
 
@@ -978,28 +852,22 @@ void MainWindow::goHomeSlot(){
 }
 
 
-void MainWindow::showInfoWindowSlot(bool isChecked){
-    qDebug() << "showInfoWindowSlot" << isChecked;
+void MainWindow::showInfoWindowSlot(){
     if(this->ui->sliderPanel->isVisible()){
         this->ui->sliderPanel->hide();
-       // this->showInfoWindowAction->setChecked(false);
-        //this->volumeDialog->getShowSeekbarButton()->setChecked(false);
+        this->showInfoWindowAction->setChecked(false);
         this->isSeekSliderShown = false;
     }else{
         this->ui->sliderPanel->show();
-       // this->showInfoWindowAction->setChecked(true);
-       //this->volumeDialog->getShowSeekbarButton()->setChecked(true);
+        this->showInfoWindowAction->setChecked(true);
         this->isSeekSliderShown = true;
     }
 
-    this->volumeDialog->hide();
     this->setActionToggleState();
 }
 
 void MainWindow::setActionToggleState(){
-    //this->showInfoWindowAction->setChecked(this->ui->subToolBar->isVisible());
-
-    //this->volumeDialog->getShowSeekbarButton()->setChecked(this->ui->subToolBar->isVisible());
+    this->showInfoWindowAction->setChecked(this->ui->subToolBar->isVisible());
     this->showToolBar2Action->setChecked(this->ui->volumePanel->isVisible());
 }
 
@@ -1106,11 +974,6 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
 
         counter++;
     }
-
-    if(this->ui->fileListWidget->selectedItems().size() > 0){
-        this->ui->fileListWidget->scrollToItem(this->ui->fileListWidget->selectedItems().value(0), QAbstractItemView::EnsureVisible);
-    }
-
 }
 
 void MainWindow::changeEvent(QEvent *e)
@@ -1128,8 +991,6 @@ void MainWindow::changeEvent(QEvent *e)
 
 void MainWindow::itemActivatedSlot(QModelIndex index)
 {
-    this->ui->fileListWidget->setCurrentIndex(index);
-
     int row = index.row();
     SymfoniePlayList *playList = this->currentPlayList;
     SymfoniePlayListItem *item = playList->get(row);
@@ -1139,27 +1000,25 @@ void MainWindow::itemActivatedSlot(QModelIndex index)
     }
 
     QString path = item->getName();
+    // qDebug() << "item index: " << index << " item at: " << path << item->getItemTypeName() << " curdir:" << this->getCurrentDiretory();
 
     if(item->getItemType() == SymfoniePlayListItem::Directory){
         this->setCurrentDirectory(path);
         this->getPlayer()->scanDir(this->getCurrentDiretory());
     }else if(item->getItemType() == SymfoniePlayListItem::DotDot){
+        //this->setCurrentDirectory(path);
         this->goUpSlot();
     }else if(item->getItemType() == SymfoniePlayListItem::File){
-
-
-        bool isCurrentDirChanged;
         if(QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0){
-            isCurrentDirChanged = false;
+
         }else{
+            //this->getPlayer()->scanDir(this->getCurrentDiretory(), true);
+
             this->getPlayer()->setPlayList(this->currentPlayList);
-            isCurrentDirChanged = true;
+
         }
 
-
-        if(row == this->getPlayer()->getCurrentPlaybackIndex() &&
-           !isCurrentDirChanged &&
-            (
+        if(row == this->getPlayer()->getCurrentPlaybackIndex() && (
                 this->player->getMediaObject()->state() == Phonon::PlayingState ||
                 this->player->getMediaObject()->state() == Phonon::PausedState
                 )){
@@ -1190,11 +1049,12 @@ void MainWindow::playSlot(){
 }
 
 void MainWindow::playNextSlot(){
+    qDebug() << "next";
     this->player->playNext();
+
+
 }
 
-
-
 void MainWindow::playPrevSlot(){
     qDebug() << "prev";
     this->player->playPrevious();
@@ -1217,9 +1077,9 @@ void MainWindow::mediaStateChangedSlot(Phonon::State newState, Phonon::State){
         // playAction->setEnabled(false);
         playAction->setIcon(style()->standardIcon(QStyle::SP_MediaPause));
         //pauseAction->setEnabled(true);
-       // stopAction->setEnabled(true);
+        stopAction->setEnabled(true);
 
-       // qDebug() << "Current playback index: " << this->player->getCurrentPlaybackIndex() ;
+        qDebug() << "Current playback index: " << this->player->getCurrentPlaybackIndex() ;
 
         if(QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0){
             this->ui->fileListWidget->setCurrentItem( this->ui->fileListWidget->item(
@@ -1230,7 +1090,7 @@ void MainWindow::mediaStateChangedSlot(Phonon::State newState, Phonon::State){
 
         break;
        case Phonon::StoppedState:
-        //stopAction->setEnabled(false);
+        stopAction->setEnabled(false);
         playAction->setEnabled(true);
         playAction->setIcon(style()->standardIcon(QStyle::SP_MediaPlay));
         //pauseAction->setEnabled(false);
@@ -1238,12 +1098,12 @@ void MainWindow::mediaStateChangedSlot(Phonon::State newState, Phonon::State){
         break;
        case Phonon::PausedState:
         //pauseAction->setEnabled(false);
-       // stopAction->setEnabled(true);
+        stopAction->setEnabled(true);
         //playAction->setEnabled(true);
         playAction->setIcon(style()->standardIcon(QStyle::SP_MediaPlay));
         break;
        case Phonon::BufferingState:
-        //qDebug() << "buffering";
+        qDebug() << "buffering";
         break;
        default:
         ;
@@ -1268,11 +1128,8 @@ void MainWindow::playerScanDirCompletedSlot(SymfoniePlayList* playList, QString
     this->setCurrentDirectory(playList->getCurrentDirectory());
     this->insertItem(playList);
 
-    if(this->forceUpdatePlayList){
-        this->getPlayer()->stop();
-        this->getPlayer()->setPlayList(playList);
-        this->forceUpdatePlayList = false;
-    }
+
+
 
 
     if(this->isResumePlayback == true){
