@@ -73,8 +73,7 @@ private:
     QAction *prevAction;
     QAction *nextAction;
     QAction *switchOrientationAction;
-    //QAction *showInfoWindowAction;
-    QAction *scanDirAction;
+    QAction *showInfoWindowAction;
     QAction *showToolBar2Action;
     QAction *goUpAction;
     QAction *goHomeAction;
@@ -82,9 +81,6 @@ private:
     QAction *toggleFullScreenAction;
     QAction *showSpeedDialogAction;
 
-    QAction *shuffleAction;
-    QAction *repeatAction;
-
     QActionGroup *orientationGroup;
     QAction *orientationLandscape;
     QAction *orientationPortrait;
@@ -107,7 +103,6 @@ private:
 
     void setMenuActionTimerText(int time);
 
-
    void setupToolBarButtonsLandscape();
    void setupToolBarButtonsPortrait();
    void setOrientationMode(int mode);
@@ -117,14 +112,11 @@ private:
 
    bool isMainToolbarVisible;
    void setToolbarVisibility(bool isShow);
-   int fileListWidgetItemIndexToDelete;
+   QString fileListWidgetItemFileToDelete;
 
-   bool forceUpdatePlayList;
-
-   bool isSubDirScanned;
 
 public Q_SLOTS:
-      void showSpeedDialogSliderChangedSlot(double);
+      void showSpeedDialogSliderChangedSlot(float);
 
 private Q_SLOTS:
     void itemActivatedSlot(QModelIndex);
@@ -136,7 +128,7 @@ private Q_SLOTS:
     void playerDirectoryChangedSlot(QString);
     void playerScanDirCompletedSlot(SymfoniePlayList*, QString);
     void switchOrientationSlot();
-    void showInfoWindowSlot(bool);
+    void showInfoWindowSlot();
     void showToolBar2Slot();
     void goHomeSlot();
     void goUpSlot();
@@ -168,13 +160,6 @@ private Q_SLOTS:
 
     void changeFileListWidgetFontSize(int size);
 
-     void supportSymfonieSlot();
-
-     void shuffleSlot(bool);
-     void repeatSlot(bool);
-
-     void scanSubFolderPressedSlot(bool);
-
 
 
 };
