@@ -2,7 +2,6 @@
 #include <QLabel>
 #include <phonon>
 #include <QStringList>
-#include <QMaemo5InformationBox>
 #include "symfonieequalizerwindow.h"
 #include "ui_symfonieequalizerwindow.h"
 #include "symfonieqslider.h"
@@ -35,8 +34,6 @@ SymfonieEqualizerWindow::SymfonieEqualizerWindow(QWidget *parent) :
 
      ui->setupUi(this);
 
-
-
     connect(this->ui->actionToggle, SIGNAL(triggered(bool)), this, SLOT(setWindowEnabled(bool)));
 
 
@@ -66,24 +63,13 @@ SymfonieEqualizerWindow::SymfonieEqualizerWindow(QWidget *parent) :
 
     }
 
-
-
 }
 
 SymfonieEqualizerWindow::~SymfonieEqualizerWindow()
 {
     delete ui;
-    qDebug() << "slider haha";
     this->saveState();
-    qDebug() << "slider haha2";
     delete this->sliderList;
-
-}
-
-void SymfonieEqualizerWindow::showEvent ( QShowEvent * event ) {
-
-    QMaemo5InformationBox::information(this, tr("Note that equalizer can be easily scrolled by dragging the numeric scale at bottom."), 5000);
-
 }
 
 void SymfonieEqualizerWindow::setEqualizerEffect(Phonon::Effect *effect){
