@@ -16,6 +16,8 @@ public:
     ~SymfonieOptionsDialog();
     bool getOptionIsShowToolbar();
     bool getOptionIsAutoResumePlayback();
+    bool getIsContinuouslyPlay();
+    int getPlayListFontSizeSbValue();
 
 protected:
     void changeEvent(QEvent *e);
