@@ -3,7 +3,6 @@
 
 #include <QObject>
 #include <QDebug>
-#include <QHash>
 #include <QFileSystemModel>
 #include "symfonieplaylistitem.h"
 #include "symfonieplaylistitemfile.h"
@@ -38,29 +37,11 @@ public:
 
     bool isIndexLast(int indexToTest);
 
-    void enableShuffle();
-    void disableShuffle();
-    bool getIsShuffleEnabled();
-
-    void enableRepeat();
-    void disableRepeat();
-    bool getIsRepeatEnabled();
-
 private:
     QString curDir;
     QList<SymfoniePlayListItem*> *itemList;
     QList<QVariant> *fileIndexList;
-    QList<QVariant> *fileIndexListBackup; //when shuffle is enabled, used for backup
     int firstFileIndex; //-1 means no file in current directory
-
-    bool isShuffleEnabled;
-
-    bool isRepeatEnabled;
-
-   void shuffleList(QList<QVariant> *  list);
-
-
-
 };
 
 #endif // SYMFONIEPLAYLIST_H
